@@ -1,9 +1,12 @@
 class Constant(object):
     MULTIPLE_COMENT_START_SYMBOL = '/*'
     MULTIPLE_COMENT_END_SYMBOL = '*/'
+    STAR = '*'
     SINGLE_COMMENT_SYMBOL = '//'
     BRACE_LEFT = '{'
     BRACE_RIGHT = '}'
+    LEFT_SQUARE_BRACKET = '['
+    RIGHT_SQUARE_BRACKET = ']'
     EQUAL_SIGN = '='
     SEMICOLON = ';'
     ANGLE_BRACKET_LEFT = '<'
