@@ -1,8 +1,5 @@
-from .proto_structures import Comment
 from .comment import CommentParser
 from .constant import Constant
-from .proto_structures import Position
-from .util import remove_prefix, remove_suffix
 
 
 class Detector(Constant):
